@@ -14,7 +14,7 @@ if [ "$1" != "snapshot" ]; then
 else
 	MODULE=$(echo "${OWNER}/${DIR}" | sed 's/^\/*//')
 	TMP="`mktemp -t -d`"
-	git clone --bare "git://git.open-mesh.org/${MODULE}.git" "${TMP}"
+	git clone --bare "https://git.open-mesh.org/${MODULE}.git" "${TMP}"
 	REV="$(git --git-dir "${TMP}" describe --long master | sed -e 's/^v*//' -e 's/-/+/g')"
 	LONGREV="$(git --git-dir "${TMP}" rev-parse master)"
 	TARNAME="${DIR}_${REV}.orig.tar"
